"""Placeholder - will be replaced by first release."""

import warnings

warnings.warn(
    "metric-datastructures version 0.0.0 is a placeholder. "
    "Install the latest version for actual functionality.",
    DeprecationWarning,
    stacklevel=2,
)

__version__ = "0.0.0"
